pub struct SecureSecret { /* private fields */ }Expand description
A resolved secret value with automatic memory zeroing on drop.
This type wraps secrecy::SecretString to ensure:
- Secret values are zeroed from memory when dropped
- Debug output shows
[REDACTED]instead of the actual value - Explicit
.expose()call required to access the value
Example
ⓘ
let secret = SecureSecret::new("my-password".to_string());
// Use the secret
let value = secret.expose();
// When `secret` goes out of scope, memory is zeroedImplementations
Sourceimpl SecureSecret
impl SecureSecret
Sourcepub fn new(value: String) -> Self
pub fn new(value: String) -> Self
Create a new secure secret from a string.
The string value is moved into secure storage and will be
automatically zeroed when this SecureSecret is dropped.